@@ -6,20 +6,21 @@ This module is used to initialize AEDT and the message manager for managing AEDT
 You can initialize this module before launching an app or
 have the app automatically initialize it to the latest installed AEDT version.
 """
-from __future__ import absolute_import
 
-import os
-import sys
-import traceback
-import logging
-import pkgutil
-import getpass
-import re
-import warnings
-import gc
-import time
+from __future__ import absolute_import  # noreorder
+
 import datetime
+import gc
+import getpass
+import logging
+import os
+import pkgutil
+import re
+import sys
 import tempfile
+import time
+import traceback
+import warnings
 
 from pyaedt import is_ironpython
 
@@ -29,8 +30,9 @@ else:
     import subprocess
 
 from pyaedt.misc import list_installed_ansysem
-from pyaedt import aedt_exception_handler, settings
+from pyaedt import pyaedt_function_handler
 from pyaedt.generic.general_methods import is_ironpython, _pythonver, inside_desktop
+from pyaedt import settings
 
 from pyaedt import aedt_logger, __version__
 
@@ -49,7 +51,7 @@ if is_ironpython:
     import clr  # IronPython C:\Program Files\AnsysEM\AnsysEM19.4\Win64\common\IronPython\ipy64.exe
 
     _com = "ironpython"
-elif IsWindows:
+elif IsWindows:  # pragma: no cover
     import pythoncom
 
     modules = [tup[1] for tup in pkgutil.iter_modules()]
@@ -63,20 +65,20 @@ elif IsWindows:
 
         _com = "pywin32"
     else:
-        raise Exception("Error. No win32com.client or Pythonnet modules found. Please install them.")
+        raise Exception("Error. No win32com.client or Pythonnet modules found. Install them and try again.")
 
 
 def exception_to_desktop(ex_value, tb_data):  # pragma: no cover
-    """Writes the trace stack to the desktop when a Python error occurs.
+    """Writes the trace stack to AEDT when a Python error occurs.
 
-    The message is added to the AEDT global message manager and to the log file (if present).
+    The message is added to the AEDT global logger and to the log file (if present).
 
     Parameters
     ----------
     ex_value : str
-        Type of exception.
+        Type of the exception.
     tb_data : str
-        Traceback information.
+        Traceback data.
 
     """
     if "aedt_logger" in dir(sys.modules["__main__"]):
@@ -152,8 +154,8 @@ def release_desktop(close_projects=True, close_desktop=True):
                 os.kill(pid, 9)
                 _delete_objects()
                 return True
-            except:
-                warnings.warn("Something went wrong in Closing AEDT")
+            except Exception:  # pragma: no cover
+                warnings.warn("Something went wrong in closing AEDT.")
                 return False
     return True
 
@@ -174,7 +176,7 @@ def force_close_desktop():
             for project in projects:
                 Module.oDesktop.CloseProject(project)
         except:
-            logger.warning("No Projects. Closing Desktop Connection")
+            logger.warning("No projects. Closing the AEDT connection.")
         try:
             i = 0
             scopeID = 5
@@ -182,7 +184,7 @@ def force_close_desktop():
                 Module.COMUtil.ReleaseCOMObjectScope(Module.COMUtil.PInvokeProxyAPI, 0)
                 i += 1
         except:
-            logger.warning("No COM UTIL. Closing the Desktop....")
+            logger.warning("No COM UTIL. Closing AEDT....")
         try:
             del Module.pyaedt_initialized
         except:
@@ -192,7 +194,7 @@ def force_close_desktop():
             del Module.oDesktop
             successfully_closed = True
         except:
-            Module.aedt_logger.error("Something went wrong in Closing AEDT.")
+            Module.aedt_logger.error("Something went wrong in closing AEDT.")
             successfully_closed = False
         finally:
             log = logging.getLogger(__name__)
@@ -204,7 +206,7 @@ def force_close_desktop():
 
 
 def run_process(command, bufsize=None):
-    """Run process with subprocess.
+    """Run process with a subprocess.
 
     Parameters
     ----------
@@ -235,6 +237,7 @@ class Desktop:
     non_graphical : bool, optional
         Whether to launch AEDT in non-graphical mode. The default
         is ``False``, in which case AEDT is launched in graphical mode.
+        This parameter is ignored when a script is launched within AEDT.
     new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the machine.
@@ -288,20 +291,31 @@ class Desktop:
             self._main.isoutsideDesktop = True
         self.release_on_exit = True
         self.logfile = None
-        if "oDesktop" in dir():
+        if "oDesktop" in dir():  # pragma: no cover
             self.release_on_exit = False
             self._main.oDesktop = oDesktop
-        elif "oDesktop" in dir(self._main) and self._main.oDesktop is not None:
+            settings.aedt_version = oDesktop.GetVersion()[0:6]
+            try:
+                settings.non_graphical = oDesktop.GetIsNonGraphical()
+            except:
+                settings.non_graphical = non_graphical
+        elif "oDesktop" in dir(self._main) and self._main.oDesktop is not None:  # pragma: no cover
             self.release_on_exit = False
+            try:
+                settings.non_graphical = self._main.oDesktop.GetIsNonGraphical()
+            except:
+                settings.non_graphical = non_graphical
         else:
+            settings.non_graphical = non_graphical
             if "oDesktop" in dir(self._main):
                 del self._main.oDesktop
             self._main.student_version, version_key, version = self._set_version(specified_version, student_version)
-            if _com == "ironpython":
-                print("Launching PyAEDT outside Electronics Desktop with IronPython")
+            settings.aedt_version = version_key
+            if _com == "ironpython":  # pragma: no cover
+                print("Launching PyAEDT outside AEDT with IronPython.")
                 self._init_ironpython(non_graphical, new_desktop_session, version)
             elif _com == "pythonnet_v3":
-                print("Launching PyAEDT outside Electronics Desktop with CPython and Pythonnet")
+                print("Launching PyAEDT outside AEDT with CPython and Pythonnet.")
                 self._init_cpython(non_graphical, new_desktop_session, version, self._main.student_version, version_key)
             else:
                 oAnsoftApp = win32com.client.Dispatch(version)
@@ -478,7 +492,7 @@ class Desktop:
         base_path = self._main.sDesktopinstallDirectory
         sys.path.append(base_path)
         sys.path.append(os.path.join(base_path, "PythonFiles", "DesktopPlugin"))
-        launch_msg = "Launching AEDT installation {}".format(base_path)
+        launch_msg = "Launching AEDT installation {}.".format(base_path)
         print(launch_msg)
         print("===================================================================================")
         clr.AddReference("Ansys.Ansoft.CoreCOMScripting")
@@ -524,7 +538,7 @@ class Desktop:
                     break
         else:
             warnings.warn(
-                "PyAEDT is not supported in AEDT versions older than 2021.2. Trying to launch it with PyWin32."
+                "PyAEDT is not supported in AEDT versions older than 2021.2. Trying to launch PyAEDT with PyWin32."
             )
             self._dispatch_win32(version)
 
@@ -545,15 +559,15 @@ class Desktop:
 
     @property
     def messenger(self):
-        """Messenger manager for the AEDT log."""
+        """Messenger manager for the AEDT logger."""
         return self._main.aedt_logger
 
     @property
     def logger(self):
-        """Logger for AEDT."""
+        """AEDT logger."""
         return self._logger
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def project_list(self):
         """Retrieve a list of projects.
 
@@ -565,7 +579,7 @@ class Desktop:
         """
         return list(self.odesktop.GetProjectList())
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def analyze_all(self, project=None, design=None):
         """Analyze all setups in a project.
 
@@ -596,7 +610,7 @@ class Desktop:
                     odesign.AnalyzeAll()
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def clear_messages(self):
         """Clear all AEDT messages.
 
@@ -608,7 +622,7 @@ class Desktop:
         self._desktop.ClearMessages("", "", 3)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def save_project(self, project_name=None, project_path=None):
         """Save the project.
 
@@ -636,7 +650,7 @@ class Desktop:
             oproject.Save()
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def copy_design(self, project_name=None, design_name=None, target_project=None):
         """Copy a design and paste it in an existing project or new project.
 
@@ -677,7 +691,7 @@ class Desktop:
                         return True
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def project_path(self, project_name=None):
         """Retrieve the path to the project.
 
@@ -701,7 +715,7 @@ class Desktop:
             return os.path.normpath(oproject.GetPath())
         return None
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def design_list(self, project=None):
         """Retrieve a list of the designs.
 
@@ -729,7 +743,7 @@ class Desktop:
                 updateddeslist.append(m.group(0))
         return updateddeslist
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def design_type(self, project_name=None, design_name=None):
         """Retrieve the type of a design.
 
@@ -813,7 +827,7 @@ class Desktop:
 
     @property
     def src_dir(self):
-        """Source directory for Python.
+        """Python source directory.
 
         Returns
         -------
@@ -836,7 +850,7 @@ class Desktop:
         return os.path.realpath(os.path.join(self.src_dir, ".."))
 
     def _exception(self, ex_value, tb_data):
-        """Write the trace stack to the desktop when a Python error occurs.
+        """Write the trace stack to AEDT when a Python error occurs.
 
         Parameters
         ----------
@@ -955,20 +969,21 @@ class Desktop:
         self._main.oDesktop.EnableAutoSave(False)
 
     def change_license_type(self, license_type="Pool"):
-        """Change the license type between ``"Pack"`` and ``"Pool"``.
+        """Change the license type.
 
         Parameters
         ----------
         license_type : str, optional
-            Type of license. The options are ``"Pack"`` and ``"Pool"``.
+            Type of the license. The options are ``"Pack"`` and ``"Pool"``.
+            The default is ``"Pool".
 
         Returns
         -------
         bool
            ``True``.
 
-             .. note::
-                Because of an API limitation, this method returns ``True`` even when the key is wrong.
+            .. note::
+               Because of an API limitation, this method returns ``True`` even when the key is wrong.
 
         """
         try:
@@ -1009,7 +1024,7 @@ class Desktop:
                 self.logger.warning("Error setting up Key %s.", key_full_name)
                 return False
         else:
-            self.logger.warning("Key Value must be an int or str.")
+            self.logger.warning("Key value must be an integer or string.")
             return False
 
     def change_active_dso_config_name(self, product_name="HFSS", config_name="Local"):
@@ -1078,7 +1093,7 @@ def get_version_env_variable(version_id):
     Parameters
     ----------
     version_id : str
-        Full AEDT version number, such as ``"2021.2"``.
+        Full AEDT version number. For example, ``"2021.2"``.
 
     Returns
     -------
