@@ -2459,6 +2459,32 @@ class EDBComponent(object):
         elif cmp_type == 0:
             return "Other"
 
+    @type.setter
+    def type(self, new_type):
+        """Set component type
+
+        Parameters
+        ----------
+        new_type : str
+            Type of the component. Options are ``"Resistor"``,  ``"Inductor"``, ``"Capacitor"``,
+            ``"IC"``, ``"IO"`` and ``"Other"``.
+        """
+        if new_type == "Resistor":
+            type_id = self._edb.Definition.ComponentType.Resistor
+        elif new_type == "Inductor":
+            type_id = self._edb.Definition.ComponentType.Inductor
+        elif new_type == "Capacitor":
+            type_id = self._edb.Definition.ComponentType.Capacitor
+        elif new_type == "IC":
+            type_id = self._edb.Definition.ComponentType.IC
+        elif new_type == "IO":
+            type_id = self._edb.Definition.ComponentType.IO
+        elif new_type == "Other":
+            type_id = self._edb.Definition.ComponentType.Other
+        else:
+            return
+        self.edbcomponent.SetComponentType(type_id)
+
     @property
     def numpins(self):
         """Number of Pins of Component.
