@@ -2,13 +2,14 @@
 This module contains EDB general methods and related methods.
 
 """
-from __future__ import absolute_import
+
+from __future__ import absolute_import  # noreorder
 
 import logging
-import warnings
 import os
+import warnings
 
-from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.generic.general_methods import pyaedt_function_handler
 
 try:
     import clr
@@ -22,7 +23,7 @@ except ImportError:
 logger = logging.getLogger(__name__)
 
 
-@aedt_exception_handler
+@pyaedt_function_handler()
 def convert_netdict_to_pydict(dict_in):
     """Convert a net dictionary to a Python dictionary.
 
@@ -43,7 +44,7 @@ def convert_netdict_to_pydict(dict_in):
     return pydict
 
 
-@aedt_exception_handler
+@pyaedt_function_handler()
 def convert_pydict_to_netdict(dict):
     """Convert a Python dictionarty to a Net dictionary.
 
@@ -62,7 +63,7 @@ def convert_pydict_to_netdict(dict):
     # to be completed
 
 
-@aedt_exception_handler
+@pyaedt_function_handler()
 def convert_py_list_to_net_list(pylist):
     """Convert a Python list to a Net list.
 
@@ -86,7 +87,7 @@ def convert_py_list_to_net_list(pylist):
         return net_list
 
 
-@aedt_exception_handler
+@pyaedt_function_handler()
 def convert_net_list_to_py_list(netlist):
     """Convert a Net list to a Python list.
 
