@@ -3,7 +3,9 @@ This module contains the `EdbHfss` class.
 """
 from pyaedt.edb_core.general import convert_netdict_to_pydict
 from pyaedt.edb_core.general import convert_py_list_to_net_list
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, is_ironpython
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import is_ironpython
+from pyaedt.generic.general_methods import pyaedt_function_handler
 
 
 class EdbHfss(object):
@@ -63,7 +65,10 @@ class EdbHfss(object):
     def _builder(self):
         return self._pedb.builder
 
-    @aedt_exception_handler
+    def _get_edb_value(self, value):
+        return self._pedb.edb_value(value)
+
+    @pyaedt_function_handler()
     def get_trace_width_for_traces_with_ports(self):
         """Retrieve the trace width for traces with ports.
 
@@ -78,7 +83,7 @@ class EdbHfss(object):
         else:
             return {}
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_circuit_port_on_pin(self, pos_pin, neg_pin, impedance=50, port_name=None):
         """Create Circuit Port on Pin.
 
@@ -106,7 +111,7 @@ class EdbHfss(object):
         """
         return self._pedb.core_siwave.create_circuit_port_on_pin(pos_pin, neg_pin, impedance, port_name)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_voltage_source_on_pin(self, pos_pin, neg_pin, voltage_value=3.3, phase_value=0, source_name=""):
         """Create a voltage source.
 
@@ -140,7 +145,7 @@ class EdbHfss(object):
             pos_pin, neg_pin, voltage_value, phase_value, source_name
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_current_source_on_pin(self, pos_pin, neg_pin, current_value=0.1, phase_value=0, source_name=""):
         """Create a current source.
 
@@ -175,7 +180,7 @@ class EdbHfss(object):
             pos_pin, neg_pin, current_value, phase_value, source_name
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_resistor_on_pin(self, pos_pin, neg_pin, rvalue=1, resistor_name=""):
         """Create a voltage source.
 
@@ -205,7 +210,7 @@ class EdbHfss(object):
         """
         return self._pedb.core_siwave.create_resistor_on_pin(pos_pin, neg_pin, rvalue, resistor_name)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_circuit_port_on_net(
         self,
         positive_component_name,
@@ -254,7 +259,7 @@ class EdbHfss(object):
             port_name,
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_voltage_source_on_net(
         self,
         positive_component_name,
@@ -307,7 +312,7 @@ class EdbHfss(object):
             source_name,
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_current_source_on_net(
         self,
         positive_component_name,
@@ -360,7 +365,7 @@ class EdbHfss(object):
             source_name,
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_resistor_on_net(
         self,
         positive_component_name,
@@ -409,7 +414,7 @@ class EdbHfss(object):
             resistor_name,
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_coax_port_on_component(self, ref_des_list, net_list):
         """Create a coaxial port on a component or component list on a net or net list.
 
@@ -449,7 +454,7 @@ class EdbHfss(object):
                         coax.append(port_name)
         return coax
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_hfss_ports_on_padstack(self, pinpos, portname=None):
         """Create a HFSS port on a padstack.
 
@@ -480,7 +485,7 @@ class EdbHfss(object):
         else:
             return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_lumped_port_on_trace(
         self,
         nets=None,
@@ -488,6 +493,7 @@ class EdbHfss(object):
         return_points_only=False,
         polygon_trace_threshhold=300e-6,
         digit_resolution=6,
+        point_list=None,
     ):
         """Create an edge port on traces.
 
@@ -509,7 +515,13 @@ class EdbHfss(object):
             ``300-e6``.
 
         digit_resolution : int, optional
-            The number of digits carried for the edges location accuracy. The default value is ``6``.
+            The number of digits carried for the edge location accuracy. The default value is ``6``.
+
+        point_list : list(tuples), optional
+            The list of points where to define ports. The port evaluation is done for each net provided and if a point
+            belongs to a center line points from a path or a polygon then the port will be created. If the point is not
+            found the ports  will be skipped. If point_list is None, the algorithm will try to find the edges from
+            traces or polygons touching the layout bounding box.
 
         Returns
         -------
@@ -529,10 +541,16 @@ class EdbHfss(object):
                 elif isinstance(nn, self._edb.Cell.Net):
                     temp_nets.append(nn)
             nets = temp_nets
+        if point_list:
+            if isinstance(point_list, tuple):
+                point_list = [point_list]
         edges_pts = []
         if nets:
             if isinstance(reference_layer, str):
-                reference_layer = self._pedb.core_stackup.signal_layers[reference_layer]._layer
+                try:
+                    reference_layer = self._pedb.core_stackup.signal_layers[reference_layer]._layer
+                except:
+                    raise Exception("Failed to get the layer {}".format(reference_layer))
             if not isinstance(reference_layer, self._edb.Cell.ILayerReadOnly):
                 return False
             layout = nets[0].GetLayout()
@@ -549,17 +567,39 @@ class EdbHfss(object):
                 ]
                 for path in net_paths:
                     trace_path_pts = list(path.GetCenterLine().Points)
-                    for pt in trace_path_pts:
-                        _pt = [round(pt.X.ToDouble(), digit_resolution), round(pt.Y.ToDouble(), digit_resolution)]
-                        if bool(set(_pt) & set(layout_bbox)):
-                            if return_points_only:
-                                edges_pts.append(_pt)
-                            else:
-                                port_name = generate_unique_name("port")
-                                if not self._hfss_terminals.CreateEdgePort(path, pt, reference_layer, port_name):
-                                    aedt_exception_handler(
-                                        "edge port creation failed on point {}, {}".format(str(pt[0]), str(_pt[1]))
+                    port_name = "{}_{}".format(net.GetName(), path.GetId())
+                    if point_list:
+                        for _pt in point_list:
+                            if isinstance(_pt, tuple):
+                                found_pt = [
+                                    p
+                                    for p in trace_path_pts
+                                    if round(p.X.ToDouble(), 6) == round(_pt[0], 6)
+                                    and round(p.Y.ToDouble(), 6) == round(_pt[1], 6)
+                                ]
+                                if found_pt:
+                                    pt = self._edb.Geometry.PointData(
+                                        self._get_edb_value(_pt[0]), self._get_edb_value(_pt[1])
                                     )
+                                    if not self._hfss_terminals.CreateEdgePort(path, pt, reference_layer, port_name):
+                                        raise Exception(
+                                            "edge port creation failed on point {}, {}".format(
+                                                str(pt.X.ToDouble()), str(pt.Y.ToDouble())
+                                            )
+                                        )
+                    else:
+                        for pt in trace_path_pts:
+                            _pt = [round(pt.X.ToDouble(), digit_resolution), round(pt.Y.ToDouble(), digit_resolution)]
+                            if bool(set(_pt) & set(layout_bbox)):
+                                if return_points_only:
+                                    edges_pts.append(_pt)
+                                else:
+                                    if not self._hfss_terminals.CreateEdgePort(
+                                        path, pt, reference_layer, port_name
+                                    ):  # pragma: no cover
+                                        raise Exception(
+                                            "edge port creation failed on point {}, {}".format(str(pt[0]), str(_pt[1]))
+                                        )
                 for poly in net_poly:
                     pt_list = list(poly.GetPolygonData().Points)
                     points_at_border = [
@@ -581,8 +621,8 @@ class EdbHfss(object):
                                 port_name = generate_unique_name("port")
                                 if not self._hfss_terminals.CreateEdgePortOnPolygon(
                                     poly, convert_py_list_to_net_list(pt_at_left), reference_layer, port_name
-                                ):
-                                    aedt_exception_handler("Failed to create port on polygon {}".format(poly.GetName()))
+                                ):  # pragma: no cover
+                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
 
                     pt_at_bottom = [
                         pt for pt in points_at_border if round(pt.Y.ToDouble(), digit_resolution) == layout_bbox[1]
@@ -597,8 +637,8 @@ class EdbHfss(object):
                                 port_name = generate_unique_name("port")
                                 if not self._hfss_terminals.CreateEdgePortOnPolygon(
                                     poly, convert_py_list_to_net_list(pt_at_bottom), reference_layer, port_name
-                                ):
-                                    aedt_exception_handler("Failed to create port on polygon {}".format(poly.GetName()))
+                                ):  # pragma: no cover
+                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
 
                     pt_at_right = [
                         pt for pt in points_at_border if round(pt.X.ToDouble(), digit_resolution) == layout_bbox[2]
@@ -613,8 +653,8 @@ class EdbHfss(object):
                                 port_name = generate_unique_name("port")
                                 if not self._hfss_terminals.CreateEdgePortOnPolygon(
                                     poly, convert_py_list_to_net_list(pt_at_right), reference_layer, port_name
-                                ):
-                                    aedt_exception_handler("Failed to create port on polygon {}".format(poly.GetName()))
+                                ):  # pragma: no cover
+                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
 
                     pt_at_top = [
                         pt for pt in points_at_border if round(pt.Y.ToDouble(), digit_resolution) == layout_bbox[3]
@@ -629,13 +669,13 @@ class EdbHfss(object):
                                 port_name = generate_unique_name("port")
                                 if not self._hfss_terminals.CreateEdgePortOnPolygon(
                                     poly, convert_py_list_to_net_list(pt_at_top), reference_layer, port_name
-                                ):
-                                    aedt_exception_handler("Failed to create port on polygon {}".format(poly.GetName()))
+                                ):  # pragma: no cover
+                                    raise Exception("Failed to create port on polygon {}".format(poly.GetName()))
             if return_points_only:
                 return edges_pts
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_layout_bounding_box(self, layout=None, digit_resolution=6):
         """Evaluate the layout bounding box.
 
