@@ -1,15 +1,14 @@
 """
 This module contains these classes: `EdbLayout` and `Shape`.
 """
-
 import math
-import warnings
 import os
+import warnings
 
-from pyaedt.edb_core.general import convert_py_list_to_net_list
-from pyaedt.generic.general_methods import aedt_exception_handler
-from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.edb_core.EDB_Data import EDBPrimitives
+from pyaedt.edb_core.general import convert_py_list_to_net_list
+from pyaedt.generic.general_methods import is_ironpython
+from pyaedt.generic.general_methods import pyaedt_function_handler
 
 try:
     from System import Tuple
@@ -26,7 +25,7 @@ class EdbLayout(object):
     --------
     >>> from pyaedt import Edb
     >>> edbapp = Edb("myaedbfolder", edbversion="2021.2")
-    >>> edb_layout = edbapp.core_layout
+    >>> edb_layout = edbapp.core_primitives
     """
 
     def __init__(self, p_edb):
@@ -39,9 +38,8 @@ class EdbLayout(object):
     def _edb(self):
         return self._pedb.edb
 
-    @property
-    def _edb_value(self):
-        return self._pedb.edb_value
+    def _get_edb_value(self, value):
+        return self._pedb.edb_value(value)
 
     @property
     def _logger(self):
@@ -80,7 +78,7 @@ class EdbLayout(object):
         """
         return self._pedb.core_stackup.stackup_layers.layers
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update_primitives(self):
         """
         Update a primitives list from the EDB database.
@@ -189,7 +187,7 @@ class EdbLayout(object):
         """
         return [i for i in self.primitives if i.type == "Polygon"]
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_polygons_by_layer(self, layer_name, net_list=None):
         """Retrieve polygons by a layer.
 
@@ -214,7 +212,7 @@ class EdbLayout(object):
                     objinst.append(el)
         return objinst
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_polygon_bounding_box(self, polygon):
         """Retrieve a polygon bounding box.
 
@@ -246,7 +244,7 @@ class EdbLayout(object):
             pass
         return bounding
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_polygon_points(self, polygon):
         """Retrieve polygon points.
 
@@ -290,7 +288,7 @@ class EdbLayout(object):
                 continue_iterate = False
         return points
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def parametrize_polygon(self, polygon, selection_polygon, offset_name="offsetx", origin=None):
         """Parametrize pieces of a polygon based on another polygon.
 
@@ -347,7 +345,7 @@ class EdbLayout(object):
 
         if not origin:
             origin = [center[0] + float(x1) * 10000, center[1] + float(y1) * 10000]
-        result, var_server = self._pedb.add_design_variable(offset_name, 0.0)
+        self._pedb.add_design_variable(offset_name, 0.0)
         i = 0
         continue_iterate = True
         prev_point = None
@@ -360,8 +358,8 @@ class EdbLayout(object):
                         xcoeff, ycoeff = calc_slope([point.X.ToDouble(), point.X.ToDouble()], origin)
 
                         new_points = self._edb.Geometry.PointData(
-                            self._edb_value(point.X.ToString() + "{}*{}".format(xcoeff, offset_name), var_server),
-                            self._edb_value(point.Y.ToString() + "{}*{}".format(ycoeff, offset_name), var_server),
+                            self._get_edb_value(point.X.ToString() + "{}*{}".format(xcoeff, offset_name)),
+                            self._get_edb_value(point.Y.ToString() + "{}*{}".format(ycoeff, offset_name)),
                         )
                         poligon_data.SetPoint(i, new_points)
                     prev_point = point
@@ -373,7 +371,7 @@ class EdbLayout(object):
         polygon.SetPolygonData(poligon_data)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_path(
         self,
         path_list,
@@ -435,14 +433,14 @@ class EdbLayout(object):
             corner_style = self._edb.Cell.Primitive.PathCornerStyle.MiterCorner  # pragma: no cover
 
         pointlists = [
-            self._edb.Geometry.PointData(self._edb_value(i[0]), self._edb_value(i[1])) for i in path_list.points
+            self._edb.Geometry.PointData(self._get_edb_value(i[0]), self._get_edb_value(i[1])) for i in path_list.points
         ]
         polygonData = self._edb.Geometry.PolygonData(convert_py_list_to_net_list(pointlists), False)
         polygon = self._edb.Cell.Primitive.Path.Create(
             self._active_layout,
             layer_name,
             net,
-            self._edb_value(width),
+            self._get_edb_value(width),
             start_cap_style,
             end_cap_style,
             corner_style,
@@ -462,7 +460,7 @@ class EdbLayout(object):
                     self._primitives_by_layer[layer_name] = [polygon]
         return polygon
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_polygon(self, main_shape, layer_name, voids=[], net_name=""):
         """Create a polygon based on a list of points and voids.
 
@@ -479,8 +477,8 @@ class EdbLayout(object):
 
         Returns
         -------
-        bool
-            ``True`` when successful, ``False`` when failed.
+        bool, :class:`pyaedt.edb_core.EDB_Data.EDBPrimitives`
+            Polygon when successful, ``False`` when failed.
         """
         net = self._pedb.core_nets.find_or_create_net(net_name)
         polygonData = self.shape_to_polygon_data(main_shape)
@@ -508,7 +506,7 @@ class EdbLayout(object):
                     self._primitives_by_layer[layer_name] = [polygon]
             return polygon
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_primitives(self, net_name=None, layer_name=None, prim_type=None, is_void=False):
         """Get primitives by conditions.
 
@@ -545,7 +543,7 @@ class EdbLayout(object):
             prims.append(el)
         return prims
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def fix_circle_void_for_clipping(self):
         """Fix issues when circle void are clipped due to a bug in EDB.
 
@@ -565,9 +563,9 @@ class EdbLayout(object):
                 self._active_layout,
                 void_circle.layer_name,
                 void_circle.net,
-                self._edb_value(center_x),
-                self._edb_value(center_y),
-                self._edb_value(radius),
+                self._get_edb_value(center_x),
+                self._get_edb_value(center_y),
+                self._get_edb_value(radius),
             )
             if res:
                 cloned_circle.SetIsNegative(True)
@@ -575,7 +573,7 @@ class EdbLayout(object):
         self.update_primitives()
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_void(self, shape, void_shape):
         """Add a void into a shape.
 
@@ -595,7 +593,7 @@ class EdbLayout(object):
         else:
             return shape.AddVoid(void_shape)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def shape_to_polygon_data(self, shape):
         """Convert a shape to polygon data.
 
@@ -612,7 +610,7 @@ class EdbLayout(object):
             self._logger.error("Unsupported shape type %s when creating a polygon primitive.", shape.type)
             return None
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _createPolygonDataFromPolygon(self, shape):
         points = shape.points
         if not self._validatePoint(points[0]):
@@ -630,8 +628,8 @@ class EdbLayout(object):
 
             if not self._validatePoint(endPoint):
                 return None
-            startPoint = [self._edb_value(i) for i in startPoint]
-            endPoint = [self._edb_value(i) for i in endPoint]
+            startPoint = [self._get_edb_value(i) for i in startPoint]
+            endPoint = [self._get_edb_value(i) for i in endPoint]
             if len(endPoint) == 2:
                 is_parametric = (
                     is_parametric
@@ -642,10 +640,10 @@ class EdbLayout(object):
                 )
                 arc = self._edb.Geometry.ArcData(
                     self._edb.Geometry.PointData(
-                        self._edb_value(startPoint[0].ToDouble()), self._edb_value(startPoint[1].ToDouble())
+                        self._get_edb_value(startPoint[0].ToDouble()), self._get_edb_value(startPoint[1].ToDouble())
                     ),
                     self._edb.Geometry.PointData(
-                        self._edb_value(endPoint[0].ToDouble()), self._edb_value(endPoint[1].ToDouble())
+                        self._get_edb_value(endPoint[0].ToDouble()), self._get_edb_value(endPoint[1].ToDouble())
                     ),
                 )
                 arcs.append(arc)
@@ -669,14 +667,14 @@ class EdbLayout(object):
                     return None
                 arc = self._edb.Geometry.ArcData(
                     self._edb.Geometry.PointData(
-                        self._edb_value(startPoint[0].ToDouble()), self._edb_value(startPoint[1].ToDouble())
+                        self._get_edb_value(startPoint[0].ToDouble()), self._get_edb_value(startPoint[1].ToDouble())
                     ),
                     self._edb.Geometry.PointData(
-                        self._edb_value(endPoint[0].ToDouble()), self._edb_value(endPoint[1].ToDouble())
+                        self._get_edb_value(endPoint[0].ToDouble()), self._get_edb_value(endPoint[1].ToDouble())
                     ),
                     rotationDirection,
                     self._edb.Geometry.PointData(
-                        self._edb_value(endPoint[3].ToDouble()), self._edb_value(endPoint[4].ToDouble())
+                        self._get_edb_value(endPoint[3].ToDouble()), self._get_edb_value(endPoint[4].ToDouble())
                     ),
                 )
                 arcs.append(arc)
@@ -686,7 +684,7 @@ class EdbLayout(object):
         else:
             k = 0
             for pt in points:
-                point = [self._edb_value(i) for i in pt]
+                point = [self._get_edb_value(i) for i in pt]
                 new_points = self._edb.Geometry.PointData(point[0], point[1])
                 if len(point) > 2:
                     k += 1
@@ -694,7 +692,7 @@ class EdbLayout(object):
                 k += 1
         return polygon
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _validatePoint(self, point, allowArcs=True):
         if len(point) == 2:
             if not isinstance(point[0], (int, float, str)):
@@ -731,8 +729,12 @@ class EdbLayout(object):
     def _createPolygonDataFromRectangle(self, shape):
         if not self._validatePoint(shape.pointA, False) or not self._validatePoint(shape.pointB, False):
             return None
-        pointA = self._edb.Geometry.PointData(self._edb_value(shape.pointA[0]), self._edb_value(shape.pointA[1]))
-        pointB = self._edb.Geometry.PointData(self._edb_value(shape.pointB[0]), self._edb_value(shape.pointB[1]))
+        pointA = self._edb.Geometry.PointData(
+            self._get_edb_value(shape.pointA[0]), self._get_edb_value(shape.pointA[1])
+        )
+        pointB = self._edb.Geometry.PointData(
+            self._get_edb_value(shape.pointB[0]), self._get_edb_value(shape.pointB[1])
+        )
         points = Tuple[self._edb.Geometry.PointData, self._edb.Geometry.PointData](pointA, pointB)
         return self._edb.Geometry.PolygonData.CreateFromBBox(points)
 
@@ -769,7 +771,7 @@ class EdbLayout(object):
             self.points = points
             self.properties = properties
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def parametrize_trace_width(self, nets_name, layers_name=None, parameter_name="trace_width", variable_value=None):
         """Parametrize a Trace on specific layer or all stackup.
 
@@ -811,7 +813,7 @@ class EdbLayout(object):
                         p.SetWidth(self._pedb.edb_value(parameter_name))
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def unite_polygons_on_layer(self, layer_name=None, delete_padstack_gemometries=False):
         """Try to unite all Polygons on specified layer.
 
