@@ -1,13 +1,15 @@
 import csv
 import os
+import tempfile
 import time
 import warnings
 from datetime import datetime
 
-from pyaedt import aedt_exception_handler
-from pyaedt.generic.constants import CSS4_COLORS, AEDT_UNITS
-from pyaedt.generic.general_methods import is_ironpython, convert_remote_object
-import tempfile
+from pyaedt import pyaedt_function_handler
+from pyaedt.generic.constants import AEDT_UNITS
+from pyaedt.generic.constants import CSS4_COLORS
+from pyaedt.generic.general_methods import convert_remote_object
+from pyaedt.generic.general_methods import is_ironpython
 
 if not is_ironpython:
     try:
@@ -77,6 +79,173 @@ def is_float(istring):
         return 0
 
 
+def plot_polar_chart(
+    plot_data, size=(2000, 1000), show_legend=True, xlabel="", ylabel="", title="", snapshot_path=None
+):
+    """Create a matplotlib polar plot based on a list of data.
+
+    Parameters
+    ----------
+    plot_data : list of list
+        List of plot data. Every item has to be in the following format
+        `[x points, y points, label]`.
+    size : tuple, optional
+        Image size in pixel (width, height).
+    show_legend : bool
+        Either to show legend or not.
+    xlabel : str
+        Plot X label.
+    ylabel : str
+        Plot Y label.
+    title : str
+        Plot Title label.
+    snapshot_path : str
+        Full path to image file if a snapshot is needed.
+    """
+    dpi = 100.0
+
+    ax = plt.subplot(111, projection="polar")
+
+    try:
+        len(plot_data)
+    except:
+        plot_data = convert_remote_object(plot_data)
+
+    label_id = 1
+    legend = []
+    for object in plot_data:
+        if len(object) == 3:
+            label = object[2]
+        else:
+            label = "Trace " + str(label_id)
+        theta = np.array(object[0])
+        r = np.array(object[1])
+        ax.plot(theta, r)
+        ax.grid(True)
+        ax.set_theta_zero_location("N")
+        ax.set_theta_direction(-1)
+        legend.append(label)
+        label_id += 1
+
+    ax.set(xlabel=xlabel, ylabel=ylabel, title=title)
+    if show_legend:
+        ax.legend(legend)
+
+    fig = plt.gcf()
+    fig.set_size_inches(size[0] / dpi, size[1] / dpi)
+    if snapshot_path:
+        fig.savefig(snapshot_path)
+    else:
+        fig.show()
+    return fig
+
+
+@pyaedt_function_handler()
+def plot_3d_chart(plot_data, size=(2000, 1000), xlabel="", ylabel="", title="", snapshot_path=None):
+    """Create a matplotlib 3D plot based on a list of data.
+
+    Parameters
+    ----------
+    plot_data : list of list
+        List of plot data. Every item has to be in the following format
+        `[x points, y points, z points, label]`.
+    size : tuple, optional
+        Image size in pixel (width, height).
+    xlabel : str
+        Plot X label.
+    ylabel : str
+        Plot Y label.
+    title : str
+        Plot Title label.
+    snapshot_path : str
+        Full path to image file if a snapshot is needed.
+
+    Returns
+    -------
+    :class:`matplotlib.plt`
+        Matplotlib fig object.
+    """
+    dpi = 100.0
+    dpi = 100.0
+
+    ax = plt.subplot(111, projection="3d")
+
+    try:
+        len(plot_data)
+    except:
+        plot_data = convert_remote_object(plot_data)
+    THETA, PHI = np.meshgrid(plot_data[0], plot_data[1])
+    R = np.array(plot_data[2])
+    X = R * np.sin(THETA) * np.cos(PHI)
+    Y = R * np.sin(THETA) * np.sin(PHI)
+    Z = R * np.cos(THETA)
+    ax.set(xlabel=xlabel, ylabel=ylabel, title=title)
+
+    ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=plt.get_cmap("jet"), linewidth=0, antialiased=True, alpha=0.5)
+    fig = plt.gcf()
+    fig.set_size_inches(size[0] / dpi, size[1] / dpi)
+    if snapshot_path:
+        fig.savefig(snapshot_path)
+    else:
+        fig.show()
+    return fig
+
+
+@pyaedt_function_handler()
+def plot_2d_chart(plot_data, size=(2000, 1000), show_legend=True, xlabel="", ylabel="", title="", snapshot_path=None):
+    """Create a matplotlib plot based on a list of data.
+
+    Parameters
+    ----------
+    plot_data : list of list
+        List of plot data. Every item has to be in the following format
+        `[x points, y points, label]`.
+    size : tuple, optional
+        Image size in pixel (width, height).
+    show_legend : bool
+        Either to show legend or not.
+    xlabel : str
+        Plot X label.
+    ylabel : str
+        Plot Y label.
+    title : str
+        Plot Title label.
+    snapshot_path : str
+        Full path to image file if a snapshot is needed.
+
+    Returns
+    -------
+    :class:`matplotlib.plt`
+        Matplotlib fig object.
+    """
+    dpi = 100.0
+    figsize = (size[0] / dpi, size[1] / dpi)
+    fig, ax = plt.subplots(figsize=figsize)
+    try:
+        len(plot_data)
+    except:
+        plot_data = convert_remote_object(plot_data)
+    label_id = 1
+    for object in plot_data:
+        if len(object) == 3:
+            label = object[2]
+        else:
+            label = "Trace " + str(label_id)
+        ax.plot(np.array(object[0]), np.array(object[1]), label=label)
+        label_id += 1
+
+    ax.set(xlabel=xlabel, ylabel=ylabel, title=title)
+    if show_legend:
+        ax.legend()
+
+    if snapshot_path:
+        fig.savefig(snapshot_path)
+    else:
+        fig.show()
+    return fig
+
+
+@pyaedt_function_handler()
 def plot_matplotlib(plot_data, size=(2000, 1000), show_legend=True, xlabel="", ylabel="", title="", snapshot_path=None):
     """Create a matplotlib plot based on a list of data.
 
@@ -97,6 +266,11 @@ def plot_matplotlib(plot_data, size=(2000, 1000), show_legend=True, xlabel="", y
         Plot Title label.
     snapshot_path : str
         Full path to image file if a snapshot is needed.
+
+    Returns
+    -------
+    :class:`matplotlib.plt`
+        Matplotlib fig object.
     """
     dpi = 100.0
     figsize = (size[0] / dpi, size[1] / dpi)
@@ -237,8 +411,8 @@ class ModelPlotter(object):
     >>> model.add_object(r'D:\Simulation\antenna.obj', (200,20,255), 0.6, "in")
     >>> model.add_object(r'D:\Simulation\helix.obj', (0,255,0), 0.5, "in")
     >>> frames = [r'D:\Simulation\helic_antenna.csv', r'D:\Simulation\helic_antenna_10.fld',
-    >>>           r'D:\Simulation\helic_antenna_20.fld', r'D:\Simulation\helic_antenna_30.fld',
-    >>>           r'D:\Simulation\helic_antenna_40.fld']
+    ...           r'D:\Simulation\helic_antenna_20.fld', r'D:\Simulation\helic_antenna_30.fld',
+    ...           r'D:\Simulation\helic_antenna_40.fld']
     >>> model.gif_file = r"D:\Simulation\animation.gif"
     >>> model.animate()
     """
@@ -390,7 +564,7 @@ class ModelPlotter(object):
     def zoom(self, value=1):
         self._zoom = value
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def set_orientation(self, camera_position="xy", roll_angle=0, azimuth_angle=45, elevation_angle=20):
         """Change the plot default orientation.
 
@@ -463,7 +637,7 @@ class ModelPlotter(object):
         """
         return self._objects
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_object(self, cad_path, cad_color="dodgerblue", opacity=1, units="mm"):
         """Add an mesh file to the scenario. It can be obj or any of pyvista supported files.
 
@@ -487,7 +661,7 @@ class ModelPlotter(object):
         self.units = units
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_field_from_file(
         self,
         field_path,
@@ -541,7 +715,7 @@ class ModelPlotter(object):
             )
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_frames_from_file(
         self,
         field_files,
@@ -593,7 +767,7 @@ class ModelPlotter(object):
             )
             self._frames[-1]._is_frame = True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_field_from_data(
         self,
         coordinates,
@@ -642,7 +816,7 @@ class ModelPlotter(object):
         filedata.point_data[self.fields[-1].label] = np.array(fields_data)
         self.fields[-1]._cached_polydata = filedata
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _triangle_vertex(self, elements_nodes, num_nodes_per_element, take_all_nodes=True):
         trg_vertex = []
         if num_nodes_per_element == 10 and take_all_nodes:
@@ -696,7 +870,7 @@ class ModelPlotter(object):
 
         return trg_vertex
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _read_mesh_files(self, read_frames=False):
         for cad in self.objects:
             if not cad._cached_polydata:
@@ -833,7 +1007,7 @@ class ModelPlotter(object):
                         filedata.point_data[field.label] = np.array(values)
                         field._cached_polydata = filedata
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _add_buttons(self):
         size = int(self.pv.window_size[1] / 40)
         startpos = self.pv.window_size[1] - 2 * size
@@ -964,7 +1138,7 @@ class ModelPlotter(object):
                 0, self.pv.button_widgets.pop(self.pv.button_widgets.index(self.pv.button_widgets[-1]))
             )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def plot(self, export_image_path=None):
         """Plot the current available Data. With `s` key a screenshot is saved in export_image_path or in tempdir.
 
@@ -1070,7 +1244,7 @@ class ModelPlotter(object):
         self.image_file = export_image_path
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def clean_cache_and_files(self, remove_objs=True, remove_fields=True, clean_cache=False):
         """Clean downloaded files, and, on demand, also the cached meshes.
 
@@ -1100,7 +1274,7 @@ class ModelPlotter(object):
                     el._cached_polydata = None
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def animate(self):
         """Animate the current field plot.
 
