@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
-from pyaedt.generic.general_methods import aedt_exception_handler, _retry_ntimes
-from pyaedt.modules.LayerStackup import Layers
+from pyaedt.generic.constants import AEDT_UNITS
+from pyaedt.generic.general_methods import _retry_ntimes
+from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.Modeler import Modeler
+from pyaedt.modeler.Object3d import _dim_arg
+from pyaedt.modeler.Object3d import CircuitComponent
 from pyaedt.modeler.Primitives3DLayout import Primitives3DLayout
 from pyaedt.modeler.PrimitivesEmit import EmitComponents
-from pyaedt.modeler.PrimitivesNexxim import NexximComponents
-from pyaedt.modeler.PrimitivesSimplorer import SimplorerComponents
 from pyaedt.modeler.PrimitivesMaxwellCircuit import MaxwellCircuitComponents
-from pyaedt.modeler.Object3d import CircuitComponent
-from pyaedt.modeler.Object3d import _dim_arg
-from pyaedt.generic.constants import AEDT_UNITS
+from pyaedt.modeler.PrimitivesNexxim import NexximComponents
+from pyaedt.modeler.PrimitivesTwinBuilder import TwinBuilderComponents
+from pyaedt.modules.LayerStackup import Layers
 
 
 class ModelerCircuit(Modeler):
@@ -55,7 +56,7 @@ class ModelerCircuit(Modeler):
         >>> oEditor.GetModelBoundingBox()"""
         return self.oeditor.GetModelBoundingBox()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def zoom_to_fit(self):
         """Zoom To Fit.
 
@@ -66,7 +67,7 @@ class ModelerCircuit(Modeler):
         """
         self.oeditor.ZoomToFit()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def connect_schematic_components(self, firstcomponent, secondcomponent, pinnum_first=2, pinnum_second=1):
         """Connect schematic components.
 
@@ -217,7 +218,7 @@ class ModelerNexxim(ModelerCircuit):
         """ Set the model units as a string e.g. "mm" """
         self.oeditor.SetActivelUnits(["NAME:Units Parameter", "Units:=", units, "Rescale:=", False])
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def move(self, selections, pos, units="meter"):
         """Move the selections by ``[x, y]``.
 
@@ -272,7 +273,7 @@ class ModelerNexxim(ModelerCircuit):
         )
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def rotate(self, selections, degrees=90):
         """Rotate the selections by degrees.
 
@@ -314,25 +315,25 @@ class ModelerNexxim(ModelerCircuit):
         return True
 
 
-class ModelerSimplorer(ModelerCircuit):
-    """ModelerSimplorer class.
+class ModelerTwinBuilder(ModelerCircuit):
+    """ModelerTwinBuilder class.
 
     Parameters
     ----------
-    app : :class:`pyaedt.application.AnalysisSimplorer.FieldAnalysisSimplorer`
+    app : :class:`pyaedt.application.AnalysisTwinBuilder.AnalysisTwinBuilder`
 
     """
 
     def __init__(self, app):
         self._app = app
         ModelerCircuit.__init__(self, app)
-        self._components = SimplorerComponents(self)
+        self._components = TwinBuilderComponents(self)
 
     @property
     def components(self):
         """
         .. deprecated:: 0.4.13
-           Use :func:`Simplorer.modeler.schematic` instead.
+           Use :func:`TwinBuilder.modeler.schematic` instead.
 
         """
         return self._components
@@ -343,7 +344,7 @@ class ModelerSimplorer(ModelerCircuit):
 
         Returns
         -------
-        :class:`pyaedt.modeler.PrimitivesSimplorer.SimplorerComponents`
+        :class:`pyaedt.modeler.PrimitivesTwinBuilder.TwinBuilderComponents`
 
         """
         return self._components
@@ -354,7 +355,7 @@ class ModelerEmit(ModelerCircuit):
 
     Parameters
     ----------
-    app : :class:`pyaedt.application.AnalysisSimplorer.FieldAnalysisSimplorer`
+    app : :class:`pyaedt.application.AnalysisEmit`
 
     """
 
