@@ -412,7 +412,7 @@ class EmitComponent(object):
         self.__dict__[property_name] = property_value
         return True
 
-    def get_prop_nodes(self, property_filter={}):
+    def get_prop_nodes(self, property_filter=None):
         """Get all property nodes that match a set of key,value pairs.
 
         Args:
@@ -423,6 +423,9 @@ class EmitComponent(object):
         Returns:
             list: All matching nodes (EmitComponentPropNode).
         """
+        if property_filter == None:
+            property_filter = {}
+
         filtered_nodes = []
         nodes_to_expand = [self.root_prop_node]
         while nodes_to_expand:
