@@ -530,7 +530,7 @@ class NexximComponents(CircuitComponents):
         return cmpid
 
     @pyaedt_function_handler()
-    def create_capacitor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
+    def create_capacitor(self, compname=None, value=50, location=None, angle=0, use_instance_id_netlist=False):
         """Create a capacitor.
 
         Parameters
@@ -557,6 +557,10 @@ class NexximComponents(CircuitComponents):
 
         >>> oEditor.CreateComponent
         """
+
+        if location == None:
+            location = []
+
         cmpid = self.create_component(
             compname,
             component_library="Capacitors",
@@ -570,7 +574,7 @@ class NexximComponents(CircuitComponents):
         return cmpid
 
     @pyaedt_function_handler()
-    def create_voltage_dc(self, compname=None, value=1, location=[], angle=0, use_instance_id_netlist=False):
+    def create_voltage_dc(self, compname=None, value=1, location=None, angle=0, use_instance_id_netlist=False):
         """Create a voltage DC source.
 
         Parameters
@@ -597,6 +601,9 @@ class NexximComponents(CircuitComponents):
 
         >>> oEditor.CreateComponent
         """
+        if location == None:
+            location = []
+
         cmpid = self.create_component(
             compname,
             component_library="Independent Sources",
@@ -757,7 +764,9 @@ class NexximComponents(CircuitComponents):
         cmpid.set_property("DC", value)
         return cmpid
 
-    def create_coupling_inductors(self, compname, l1, l2, value=1, location=[], angle=0, use_instance_id_netlist=False):
+    def create_coupling_inductors(
+        self, compname, l1, l2, value=1, location=None, angle=0, use_instance_id_netlist=False
+    ):
         """Create a coupling inductor.
 
         Parameters
@@ -788,6 +797,9 @@ class NexximComponents(CircuitComponents):
 
         >>> oEditor.CreateComponent
         """
+        if location == None:
+            location = []
+
         cmpid = self.create_component(
             compname,
             component_library="Inductors",
