@@ -1,15 +1,17 @@
 """
 This module contains the `Mesh` class.
 """
+from __future__ import absolute_import  # noreorder
 
-from __future__ import absolute_import
 import os
 import shutil
 from collections import OrderedDict
 
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, MethodNotSupportedError
 from pyaedt.application.design_solutions import model_names
 from pyaedt.generic.DataHandlers import _dict2arg
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import MethodNotSupportedError
+from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.generic.LoadAEDTFile import load_entire_aedt_file
 
 meshers = {
@@ -24,6 +26,32 @@ meshers = {
 }
 
 
+class MeshProps(OrderedDict):
+    """AEDT Mesh Component Internal Parameters."""
+
+    def __setitem__(self, key, value):
+        OrderedDict.__setitem__(self, key, value)
+        if key in ["Edges", "Faces", "Objects"]:
+            res = self._pyaedt_mesh.update_assignment()
+        else:
+            res = self._pyaedt_mesh.update()
+        if not res:
+            self._pyaedt_mesh._app.logger.warning("Update of %s Failed. Check needed arguments", key)
+
+    def __init__(self, mesh_object, props):
+        OrderedDict.__init__(self)
+        if props:
+            for key, value in props.items():
+                if isinstance(value, (OrderedDict, OrderedDict)):
+                    OrderedDict.__setitem__(self, key, MeshProps(mesh_object, value))
+                else:
+                    OrderedDict.__setitem__(self, key, value)
+        self._pyaedt_mesh = mesh_object
+
+    def _setitem_without_update(self, key, value):
+        OrderedDict.__setitem__(self, key, value)
+
+
 class MeshOperation(object):
     """MeshOperation class.
 
@@ -42,10 +70,10 @@ class MeshOperation(object):
     def __init__(self, meshicepak, name, props, meshoptype):
         self._meshicepak = meshicepak
         self.name = name
-        self.props = props
+        self.props = MeshProps(self, props)
         self.type = meshoptype
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_args(self):
         """Retrieve arguments."""
         props = self.props
@@ -53,7 +81,7 @@ class MeshOperation(object):
         _dict2arg(props, arg)
         return arg
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create(self):
         """Create a mesh.
 
@@ -87,7 +115,7 @@ class MeshOperation(object):
             return False
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update(self):
         """Update the mesh.
 
@@ -136,7 +164,7 @@ class MeshOperation(object):
             return False
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete(self):
         """Delete the mesh.
 
@@ -210,7 +238,7 @@ class Mesh(object):
         """
         return self._omeshmodule
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_design_global_mesh(self):
         """ """
         props = None
@@ -220,7 +248,13 @@ class Mesh(object):
             temp_name = generate_unique_name("temp_prj")
             temp_proj = os.path.join(self._app.working_directory, temp_name + ".aedt")
             oproject_target = self._app.odesktop.NewProject(temp_name)
-            des_target = oproject_target.InsertDesign(self._app.design_type, temp_name, self._app.solution_type, "")
+            if self._app.solution_type == "Modal":
+                sol = "HFSS Modal Network"
+            elif self._app.solution_type == "Terminal":
+                sol = "HFSS Terminal Network"
+            else:
+                sol = self._app.solution_type
+            oproject_target.InsertDesign(self._app.design_type, temp_name, sol, "")
             oproject_target.SaveAs(temp_proj, True)
             self._app.odesktop.CloseProject(temp_name)
             _project_dictionary = load_entire_aedt_file(temp_proj)
@@ -239,7 +273,7 @@ class Mesh(object):
             return bound
         return OrderedDict()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_design_mesh_operations(self):
         """ """
         meshops = []
@@ -258,7 +292,7 @@ class Mesh(object):
             pass
         return meshops
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_surface_mesh(self, names, level, meshop_name=None):
         """Assign a surface mesh level to one or more objects.
 
@@ -308,7 +342,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_surface_mesh_manual(self, names, surf_dev=None, normal_dev=None, aspect_ratio=None, meshop_name=None):
         """Assign a surface mesh to a list of faces.
 
@@ -378,7 +412,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_model_resolution(self, names, defeature_length=None, meshop_name=None):
         """Assign the model resolution.
 
@@ -431,7 +465,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_initial_mesh_from_slider(
         self,
         level=5,
@@ -523,7 +557,7 @@ class Mesh(object):
         self.omeshmodule.InitialMeshSettings(args)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_surf_priority_for_tau(self, object_lists, surfpriority=0):
         """Assign a surface representation priority for the TAU mesh.
 
@@ -552,7 +586,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def generate_mesh(self, name):
         """Generate the mesh for a design.
 
@@ -573,7 +607,7 @@ class Mesh(object):
         """
         return self._odesign.GenerateMesh(name) == 0
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete_mesh_operations(self, mesh_type=None):
         """Remove mesh operations from a design.
 
@@ -612,7 +646,7 @@ class Mesh(object):
 
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_length_mesh(self, names, isinside=True, maxlength=1, maxel=1000, meshop_name=None):
         """Assign a length for the model resolution.
 
@@ -693,7 +727,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_skin_depth(
         self, names, skindepth, maxelements=None, triangulation_max_length="0.1mm", numlayers="2", meshop_name=None
     ):
@@ -770,7 +804,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_curvilinear_elements(self, names, enable=True, meshop_name=None):
         """Assign curvilinear elements.
 
@@ -820,7 +854,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_curvature_extraction(self, names, disable_for_faceted_surf=True, meshop_name=None):
         """Assign curvature extraction.
 
@@ -872,7 +906,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_rotational_layer(self, names, num_layers=3, total_thickness="1mm", meshop_name=None):
         """Assign a rotational layer mesh.
 
@@ -923,7 +957,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_edge_cut(self, names, layer_thickness="1mm", meshop_name=None):
         """Assign an edge cut layer mesh.
 
@@ -964,7 +998,7 @@ class Mesh(object):
         self.meshoperations.append(mop)
         return mop
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_density_control(self, names, refine_inside=True, maxelementlength=None, layerNum=None, meshop_name=None):
         """Assign density control.
 
